Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(11641)

Unified Diff: chromeos/chromeos_paths.h

Issue 25242002: Support policies referencing external data for device-local accounts (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebased. Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/chrome_tests.gypi ('k') | chromeos/chromeos_paths.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/chromeos_paths.h
diff --git a/chromeos/chromeos_paths.h b/chromeos/chromeos_paths.h
index 0627ded1bd5e997358bc2988c770f0792cb36850..d25ac437c5d515e16d7a223143f24691a74ea881 100644
--- a/chromeos/chromeos_paths.h
+++ b/chromeos/chromeos_paths.h
@@ -27,10 +27,13 @@ enum {
// store the uptime at which an update
// became necessary. The file should be
// cleared on boot.
- DIR_DEVICE_LOCAL_ACCOUNT_CACHE, // Directory under which a cache of
- // force-installed extensions is maintained
- // for each device-local account.
-
+ DIR_DEVICE_LOCAL_ACCOUNT_EXTENSIONS, // Directory under which a cache of
+ // force-installed extensions is
+ // maintained for each device-local
+ // account.
+ DIR_DEVICE_LOCAL_ACCOUNT_EXTERNAL_DATA, // Directory where external data
+ // referenced by policies is cached
+ // for device-local accounts.
PATH_END
};
« no previous file with comments | « chrome/chrome_tests.gypi ('k') | chromeos/chromeos_paths.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698